Improve this Doc View Source

Returns a function which calls function `fn` bound to `self` (`self` becomes the `this` for `fn`). You can supply optional `args` that are prebound to the function. This feature is also known as partial application, as distinguished from function currying.

## Usage

`angular.bind(self, fn, args);`

### Arguments

Param | Type | Details
--- | --- | ---
self | Object | Context which `fn` should be evaluated in.
fn | function() | Function to be bound.
args | * | Optional arguments to be prebound to the `fn` function call.

### Returns

function() | Function that wraps the `fn` with all the specified bindings.